@@ -1,4 +1,4 @@
-# Copyright 2018-2019 Descartes Labs.
+# Copyright 2018-2020 Descartes Labs.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,6 @@
 import json
 import os
 import itertools
-from warnings import simplefilter
 from six import string_types
 from descarteslabs.client.services.service import Service
 from descarteslabs.client.services.places import Places
@@ -57,7 +56,6 @@ class Metadata(Service):
         if auth is None:
             auth = Auth()
 
-        simplefilter("always", DeprecationWarning)
         if url is None:
             url = os.environ.get(
                 "DESCARTESLABS_METADATA_URL",
@@ -852,11 +850,13 @@ class Metadata(Service):
             >>> keys = list(meta.keys())
             >>> keys.sort()
             >>> keys
-            ['acquired', 'area', 'bits_per_pixel', 'bright_fraction', 'bucket', 'cloud_fraction',
-             'cloud_fraction_0', 'confidence_dlsr', 'cs_code', 'descartes_version', 'file_md5s', 'file_sizes',
-             'files', 'fill_fraction', 'geolocation_accuracy', 'geometry', 'geotrans', 'id', 'identifier',
-             'key', 'processed', 'product', 'proj4', 'projcs', 'published', 'raster_size', 'reflectance_scale',
-             'roll_angle', 'sat_id', 'solar_azimuth_angle', 'solar_elevation_angle', 'storage_state',
+            ['acquired', 'area', 'bits_per_pixel', 'bright_fraction', 'bucket',
+             'cloud_fraction', 'cloud_fraction_0', 'confidence_dlsr', 'cs_code',
+             'descartes_version', 'file_md5s', 'file_sizes', 'files', 'fill_fraction',
+             'geolocation_accuracy', 'geometry', 'geotrans', 'id', 'identifier', 'key',
+             'owner_type', 'processed', 'product', 'proj4', 'projcs', 'published',
+             'raster_size', 'reflectance_scale', 'roll_angle', 'sat_id',
+             'solar_azimuth_angle', 'solar_elevation_angle', 'storage_state',
              'sw_version', 'terrain_correction', 'tile_id']
         """
         r = self.session.get("/get/{}".format(image_id))
