@@ -4,9 +4,8 @@ import pytest
 
 from descarteslabs.common.proto.workflow import workflow_pb2
 
-from descarteslabs.workflows import _channel
 from descarteslabs.workflows.client import Client
-from descarteslabs.workflows.models import Workflow
+from descarteslabs.workflows.models import Workflow, wmts_url
 from descarteslabs.workflows.models.utils import pb_milliseconds_to_datetime
 from descarteslabs.workflows.models.tests import utils
 from descarteslabs.workflows.types import Int, Function
@@ -47,7 +46,7 @@ class TestWorkflow(object):
             stub.return_value.GetWorkflow.assert_called_once_with(
                 workflow_pb2.GetWorkflowRequest(id="fake_id"),
                 timeout=Client.DEFAULT_TIMEOUT,
-                metadata=(("x-wf-channel", _channel.__channel__),),
+                metadata=mock.ANY,
             )
 
     def test_delete_id(self, stub):
@@ -56,7 +55,7 @@ class TestWorkflow(object):
         stub.return_value.DeleteWorkflow.assert_called_once_with(
             workflow_pb2.DeleteWorkflowRequest(id=workflow_id),
             timeout=Client.DEFAULT_TIMEOUT,
-            metadata=(("x-wf-channel", _channel.__channel__),),
+            metadata=mock.ANY,
         )
 
     def test_delete(self, stub):
@@ -66,7 +65,7 @@ class TestWorkflow(object):
         stub.return_value.DeleteWorkflow.assert_called_once_with(
             workflow_pb2.DeleteWorkflowRequest(id=workflow_id),
             timeout=Client.DEFAULT_TIMEOUT,
-            metadata=(("x-wf-channel", _channel.__channel__),),
+            metadata=mock.ANY,
         )
 
     def test_save(self, stub):
@@ -96,7 +95,7 @@ class TestWorkflow(object):
                 tags=old_message.tags,
             ),
             timeout=Client.DEFAULT_TIMEOUT,
-            metadata=(("x-wf-channel", _channel.__channel__),),
+            metadata=mock.ANY,
         )
 
     def test_set_version(self, stub):
@@ -217,3 +216,44 @@ class TestWorkflow(object):
         assert wf.name == "test"
         assert wf.created_timestamp == pb_milliseconds_to_datetime(100)
         assert wf.updated_timestamp == pb_milliseconds_to_datetime(200)
+
+    def test_workflow_wmts_url(self, stub):
+        wf = Workflow(
+            id="bob@gmail.com:test",
+            title="test",
+            description="a test",
+            public=True,
+            labels={"foo": "bar"},
+            tags=["foo", "bar"],
+        )
+
+        wmts_url_template = "http://base.net/wmts/workflow/bob@gmail.com:test/1.0.0/WMTSCapabilities.xml"
+        wf._message.wmts_url_template = wmts_url_template
+
+        assert wf.wmts_url() == wmts_url_template
+        assert (
+            wf.wmts_url(tile_matrix_sets="utm")
+            == wmts_url_template + "?tile_matrix_sets=utm"
+        )
+        assert (
+            wf.wmts_url(tile_matrix_sets=["EPSG:4326", "EPSG:3857"])
+            == wmts_url_template
+            + "?tile_matrix_sets=EPSG%3A4326&tile_matrix_sets=EPSG%3A3857"
+        )
+
+    def test_wmts_url(self, stub):
+        wmts_url_template = "http://base.net/wmts/workflow/1.0.0/WMTSCapabilities.xml"
+        response = workflow_pb2.WmtsUrlTemplateResponse()
+        response.wmts_url_template = wmts_url_template
+        stub.return_value.GetWmtsUrlTemplate.return_value = response
+
+        assert wmts_url() == wmts_url_template
+        assert (
+            wmts_url(tile_matrix_sets="utm")
+            == wmts_url_template + "?tile_matrix_sets=utm"
+        )
+        assert (
+            wmts_url(tile_matrix_sets=["EPSG:4326", "EPSG:3857"])
+            == wmts_url_template
+            + "?tile_matrix_sets=EPSG%3A4326&tile_matrix_sets=EPSG%3A3857"
+        )
