@@ -1,4 +1,3 @@
-from ... import env
 from .dtype import DType
 from .scalar import Scalar
 from ..containers import Dict, KnownDict, Ellipsis as wf_Ellipsis, List, Slice, Tuple
@@ -195,7 +194,7 @@ class BaseArray(NumPyMixin, Proxytype):
             )
 
         return ImageCollection._from_apply(
-            "wf.to_imagery", self, properties, bandinfo, env.geoctx
+            "wf.to_imagery", self, properties, bandinfo
         )
 
     def __getitem__(self, idx):
@@ -413,7 +412,7 @@ class BaseArray(NumPyMixin, Proxytype):
         mask=False,
         fill_value=1e+20)
         """
-        return self._stats_return_type(axis)._from_apply("wf.median", self, axis=axis)
+        return _delayed_numpy().median(self, axis)
 
     def sum(self, axis=None):
         """ Sum along a given axis.
