@@ -1,8 +1,8 @@
 import six
+import logging
 
 from descarteslabs import scenes
 
-from ... import env
 from ...cereal import serializable
 from ..array import MaskedArray
 from ..containers import Dict, KnownDict, Struct, Tuple, List
@@ -210,26 +210,20 @@ class Image(ImageBase, BandsMixin):
             "q1",
             "q3",
         ]:
-            raise ValueError(
-                "Unknown resampler type: {}".format(resampler.literal_value)
-            )
+            raise ValueError(f"Unknown resampler type: {resampler.literal_value!r}")
         if (
             processing_level.literal_value is not None
             and processing_level.literal_value not in ("toa", "surface")
         ):
             raise ValueError(
-                "Unknown processing level: {!r}. Must be None, 'toa', or 'surface'.".format(
-                    processing_level.literal_value
-                )
+                f"Unknown processing level: {processing_level.literal_value!r}. "
+                "Must be None, 'toa', or 'surface'."
             )
         return cls._from_apply(
             "wf.Image.load",
             image_id,
-            geocontext=env.geoctx,
-            token=env._token,
             resampler=resampler,
             processing_level=processing_level,
-            ruster=env._ruster,
         )
 
     @classmethod
@@ -455,9 +449,17 @@ class Image(ImageBase, BandsMixin):
             or `~.workflows.types.geospatial.FeatureCollection`),
             in which case pixels *outside* the vector are masked.
         replace: Bool, default False
-            If False (default), adds this mask to the current one,
-            so already-masked pixels remain masked,
-            or replaces the current mask with this new one if True.
+            Whether to add to the Image's current mask, or replace it.
+
+            If False (default):
+
+            * Adds this mask to the current one, so already-masked pixels remain masked.
+            * Masked-out pixels in the `mask` are ignored (considered False).
+
+            If True:
+
+            * Replaces the current mask with this new one.
+            * Masked-out pixels in the `mask` are also masked in the result.
 
         Example
         -------
@@ -544,6 +546,11 @@ class Image(ImageBase, BandsMixin):
         if cls._RESOLVED_STATS_RETURN_TYPES is None:
             cls._RESOLVED_STATS_RETURN_TYPES = _resolve_lambdas(cls._STATS_RETURN_TYPES)
 
+        if isinstance(axis, list):
+            axis = tuple(axis)
+        if isinstance(axis, tuple) and len(axis) == 1:
+            axis = axis[0]
+
         try:
             return cls._RESOLVED_STATS_RETURN_TYPES[axis]
         except KeyError:
@@ -831,6 +838,64 @@ class Image(ImageBase, BandsMixin):
         axis = list(axis) if isinstance(axis, tuple) else axis
         return return_type._from_apply("wf.count", self, axis)
 
+    @typecheck_promote(operation=Str)
+    def reduction(self, operation, axis=None):
+        """
+        Reduction along the provided ``axis``, or across all pixels in the image
+        if no ``axis`` argument is provided.
+
+        If the `Image` is empty, an empty (of the type determined by ``axis``) will be returned.
+
+        Parameters
+        ----------
+        operation: {"min", "max", "mean", "median", "sum", "std", "count"}
+            A string indicating the reduction method to apply along the specified axis.
+        axis: {None, "pixels", "bands"}
+            A Python string indicating the axis along which to perform the reduction.
+
+            Options:
+
+            * ``"pixels"``: Returns a ``Dict[Str, Float]`` containing the reduction
+              across each band.
+            * ``"bands"``: Returns a new `.Image` with
+              one band, ``"std"``, containing the reduction across all bands
+              for each pixel.
+            * ``None``: Returns a `.Float` that represents the reduction of the
+              entire image.
+
+        Returns
+        -------
+        ``Dict[Str, Float]`` or `.Image` or `.Float`
+            Reduction along the provided ``axis``.  See the options for the ``axis``
+            argument for details.
+
+        Example
+        -------
+        >>> import descarteslabs.workflows as wf
+        >>> img = wf.Image.from_id("landsat:LC08:01:RT:TOAR:meta_LC08_L1TP_033035_20170516_20170516_01_RT_v1")
+        >>> std_img = img.reduction("std", axis="bands")
+        >>> band_stds = img.reduction("std", axis="pixels")
+        >>> std = img.reduction("std", axis=None)
+        """
+        if operation.literal_value is not None and operation.literal_value not in [
+            "min",
+            "max",
+            "mean",
+            "median",
+            "sum",
+            "std",
+            "count",
+        ]:
+            raise ValueError(
+                "Invalid operation {!r}, must be 'min', 'max', 'mean', 'median', 'sum', 'std', or 'count'.".format(
+                    operation.literal_value
+                )
+            )
+
+        return_type = self._stats_return_type(axis)
+        axis = list(axis) if isinstance(axis, tuple) else axis
+        return return_type._from_apply("wf.reduction", self, operation, axis=axis)
+
     # Binary comparators
     @typecheck_promote((lambda: Image, lambda: _DelayedImageCollection(), Int, Float))
     def __lt__(self, other):
@@ -1434,7 +1499,13 @@ class Image(ImageBase, BandsMixin):
         return _result_type(other)._from_apply("wf.pow", other, self)
 
     def tile_layer(
-        self, name=None, scales=None, colormap=None, checkerboard=True, **parameters
+        self,
+        name=None,
+        scales=None,
+        colormap=None,
+        checkerboard=True,
+        log_level=logging.DEBUG,
+        **parameter_overrides,
     ):
         """
         A `.WorkflowsLayer` for this `Image`.
@@ -1463,11 +1534,28 @@ class Image(ImageBase, BandsMixin):
             The name of the colormap to apply to the `Image`. Only valid if the `Image` has a single band.
         checkerboard: bool, default True
             Whether to display a checkerboarded background for missing or masked data.
-        **parameters: JSON-serializable value, Proxytype, or ipywidgets.Widget
-            Runtime parameters to use when computing tiles.
-            Values can be any JSON-serializable value, a `Proxytype` instance, or an ipywidgets ``Widget``.
+        log_level: int, default logging.DEBUG
+            Only listen for log records at or above this log level during tile computation.
+            See https://docs.python.org/3/library/logging.html#logging-levels for valid
+            log levels.
+        **parameter_overrides: JSON-serializable value, Proxytype, or ipywidgets.Widget
+            Values---or ipywidgets---for any parameters that this `Image` depends on.
 
-            See the docstring for `visualize` for more detail.
+            If this `Image` depends on ``wf.widgets``, you don't have to pass anything for those---any
+            widgets it depends on are automatically linked to the layer. However, you can override
+            their current values (or widgets) by passing new values (or ipywidget instances) here.
+
+            Values can be given as Proxytypes, or as Python objects like numbers,
+            lists, and dicts that can be promoted to them.
+            These arguments cannot depend on any parameters.
+
+            If an ``ipywidgets.Widget`` is given, it's automatically linked, so updating the widget causes
+            the argument value to change, and the layer to update.
+
+            Once these initial argument values are set, they can be modified by assigning to
+            `~.WorkflowsLayer.parameters` on the returned `WorkflowsLayer`.
+
+            For more information, see the docstring to `ParameterSet`.
 
         Returns
         -------
@@ -1475,11 +1563,15 @@ class Image(ImageBase, BandsMixin):
         """
         from ... import interactive
 
-        layer = interactive.WorkflowsLayer(self, name=name, parameters=parameters)
-        layer.set_scales(scales, new_colormap=colormap)
-        layer.checkerboard = checkerboard
-
-        return layer
+        return interactive.WorkflowsLayer(
+            self,
+            name=name,
+            scales=scales,
+            colormap=colormap,
+            checkerboard=checkerboard,
+            log_level=log_level,
+            parameter_overrides=parameter_overrides,
+        )
 
     def visualize(
         self,
@@ -1487,13 +1579,14 @@ class Image(ImageBase, BandsMixin):
         scales=None,
         colormap=None,
         checkerboard=True,
+        log_level=logging.DEBUG,
         map=None,
-        **parameters
+        **parameter_overrides,
     ):
         """
         Add this `Image` to `wf.map <.interactive.map>`, or replace a layer with the same name.
 
-        An empty  `Image` will be rendered as a checkerboard (default) or blank tile.
+        An empty `Image` will be rendered as a checkerboard (default) or blank tile.
 
         Parameters
         ----------
@@ -1518,24 +1611,31 @@ class Image(ImageBase, BandsMixin):
             The name of the colormap to apply to the `Image`. Only valid if the `Image` has a single band.
         checkerboard: bool, default True
             Whether to display a checkerboarded background for missing or masked data.
+        log_level: int, default logging.DEBUG
+            Only listen for log records at or above this log level during tile computation.
+            See https://docs.python.org/3/library/logging.html#logging-levels for valid
+            log levels.
         map: `.Map` or `.MapApp`, optional, default None
             The `.Map` (or plain ipyleaflet Map) instance on which to show the `Image`.
             If None (default), uses `wf.map <.interactive.map>`, the singleton Workflows `.MapApp` object.
-        **parameters: JSON-serializable value, Proxytype, or ipywidgets.Widget
-            Runtime parameters to use when computing tiles.
-            Values can be any JSON-serializable value, a `Proxytype` instance, or an ipywidgets ``Widget``.
+        **parameter_overrides: JSON-serializable value, Proxytype, or ipywidgets.Widget
+            Values---or ipywidgets---for any parameters that this `Image` depends on.
 
-            Once these initial parameter values are set, they can be modified by assigning to
+            If this `Image` depends on ``wf.widgets``, you don't have to pass anything for those---any
+            widgets it depends on are automatically linked to the layer. However, you can override
+            their current values (or widgets) by passing new values (or ipywidget instances) here.
+
+            Values can be given as Proxytypes, or as Python objects like numbers,
+            lists, and dicts that can be promoted to them.
+            These arguments cannot depend on any parameters.
+
+            If an ``ipywidgets.Widget`` is given, it's automatically linked, so updating the widget causes
+            the argument value to change, and the map to update. Running `visualize` again and passing in
+            a different widget instance will un-link the old one automatically.
+
+            Once these initial argument values are set, they can be modified by assigning to
             `~.WorkflowsLayer.parameters` on the returned `WorkflowsLayer`.
 
-            If a Widget is given, it's automatically linked, so updating the widget causes the parameter
-            value to change, and the map to update. Running `visualize` again and passing in a different
-            widget instance will un-link the old one automatically.
-
-            If a Python value or `Proxytype` is given, values you later assign to that parameter
-            must be of a compatible type (for example, you can't give ``threshold=0.6``, then assign
-            ``lyr.parameters.threshold = "foo"``, because ``"foo"`` can't be cast to a float).
-
             For more information, see the docstring to `ParameterSet`.
 
         Returns
@@ -1570,11 +1670,12 @@ class Image(ImageBase, BandsMixin):
 
         for layer in map.layers:
             if layer.name == name:
-                with layer.hold_trait_notifications():
-                    layer.image = self
+                with layer.hold_url_updates():
+                    layer.set_imagery(self, **parameter_overrides)
                     layer.set_scales(scales, new_colormap=colormap)
                     layer.checkerboard = checkerboard
-                    layer.set_parameters(**parameters)
+                    if log_level is not None:
+                        layer.log_level = log_level
                 return layer
         else:
             layer = self.tile_layer(
@@ -1582,7 +1683,8 @@ class Image(ImageBase, BandsMixin):
                 scales=scales,
                 colormap=colormap,
                 checkerboard=checkerboard,
-                **parameters
+                log_level=log_level,
+                **parameter_overrides,
             )
             map.add_layer(layer)
             return layer
