@@ -5,7 +5,6 @@ import six
 from descarteslabs import scenes
 from ...core.tests import utils
 
-from .... import env
 from ...core import ProxyTypeError, _resolve_lambdas
 from ...primitives import Str, Float, Int, Bool, NoneType, Any
 from ...containers import Dict, Tuple
@@ -18,18 +17,16 @@ def test_init_raises():
         Image()
 
 
-@mock.patch.object(env, "geoctx")
-@mock.patch.object(env, "_token")
-def test_from_id(mock_geoctx, mock_token):
-    mock_geoctx_graft = mock.PropertyMock(return_value={"returns": "geoctx"})
-    mock_token_graft = mock.PropertyMock(return_value={"returns": "_token_"})
-    type(mock_geoctx).graft = mock_geoctx_graft
-    type(mock_token).graft = mock_token_graft
-    # "Because of the way mock attributes are stored you can't directly attach a PropertyMock to a mock object.
-    # Instead you can attach it to the mock type object."
-    Image.from_id("foo")
-    mock_geoctx_graft.assert_called()
-    mock_token_graft.assert_called()
+def test_from_id():
+    assert isinstance(Image.from_id("foo"), Image)
+    assert isinstance(
+        Image.from_id("foo", resampler="near", processing_level="toa"), Image
+    )
+
+    with pytest.raises(ValueError, match="Unknown resampler type: 'foo'"):
+        Image.from_id("foo", resampler="foo")
+    with pytest.raises(ValueError, match="Unknown processing level: 'foo'"):
+        Image.from_id("foo", processing_level="foo")
 
 
 @mock.patch.object(Image, "from_id", wraps=Image.from_id)
@@ -47,8 +44,12 @@ def test_promote(from_id_wrapper):
         Image._promote("")
 
 
-def test_stats_return_type():
+@pytest.mark.parametrize("listify", [False, True])
+@pytest.mark.parametrize("singleton_tupleify", [False, True])
+def test_stats_return_type(listify, singleton_tupleify):
     for axis, return_type in six.iteritems(_resolve_lambdas(Image._STATS_RETURN_TYPES)):
+        axis = (axis,) if singleton_tupleify and not isinstance(axis, tuple) else axis
+        axis = list(axis) if listify and isinstance(axis, tuple) else axis
         assert Image._stats_return_type(axis) == return_type
 
     with pytest.raises(ValueError):
@@ -121,6 +122,34 @@ def test_all_methods():
     assert isinstance(img.count(axis="bands"), Image)
     assert isinstance(img.count(axis=None), Float)
     assert isinstance(img.count(), Float)
+    assert isinstance(img.reduction("min", axis="pixels"), Dict[Str, Float])
+    assert isinstance(img.reduction("min", axis="bands"), Image)
+    assert isinstance(img.reduction("min", axis=None), Float)
+    assert isinstance(img.reduction("min"), Float)
+    assert isinstance(img.reduction("max", axis="pixels"), Dict[Str, Float])
+    assert isinstance(img.reduction("max", axis="bands"), Image)
+    assert isinstance(img.reduction("max"), Float)
+    assert isinstance(img.reduction("max", axis=None), Float)
+    assert isinstance(img.reduction("mean", axis="pixels"), Dict[Str, Float])
+    assert isinstance(img.reduction("mean", axis="bands"), Image)
+    assert isinstance(img.reduction("mean", axis=None), Float)
+    assert isinstance(img.reduction("mean"), Float)
+    assert isinstance(img.reduction("median", axis="pixels"), Dict[Str, Float])
+    assert isinstance(img.reduction("median", axis="bands"), Image)
+    assert isinstance(img.reduction("median", axis=None), Float)
+    assert isinstance(img.reduction("median"), Float)
+    assert isinstance(img.reduction("sum", axis="pixels"), Dict[Str, Float])
+    assert isinstance(img.reduction("sum", axis="bands"), Image)
+    assert isinstance(img.reduction("sum", axis=None), Float)
+    assert isinstance(img.reduction("sum"), Float)
+    assert isinstance(img.reduction("std", axis="pixels"), Dict[Str, Float])
+    assert isinstance(img.reduction("std", axis="bands"), Image)
+    assert isinstance(img.reduction("std", axis=None), Float)
+    assert isinstance(img.reduction("std"), Float)
+    assert isinstance(img.reduction("count", axis="pixels"), Dict[Str, Float])
+    assert isinstance(img.reduction("count", axis="bands"), Image)
+    assert isinstance(img.reduction("count", axis=None), Float)
+    assert isinstance(img.reduction("count"), Float)
 
 
 img = Image.from_id("bar")
