@@ -1,13 +1,12 @@
 import pytest
-import mock
 import six
 
 from ...core import _resolve_lambdas
 from ...core.tests import utils
 
-from .... import env
 from ...containers import Dict, List, Slice, Tuple
 from ...primitives import Float, Int, Str, Bool, NoneType, Any
+from ...identifier import parameter
 
 from .. import (
     Image,
@@ -27,56 +26,32 @@ def thaw_axis(frozen_axis):
 
 
 def test_init():
-    ImageCollection([Image.from_id("foo")])
+    x = parameter("x", Image)
+    ic = ImageCollection([Image.from_id("foo"), x])
+    assert ic.params == (x,)
 
     with pytest.raises(TypeError):
         ImageCollection("", "")
 
 
-@mock.patch.object(env, "geoctx")
-@mock.patch.object(env, "_token")
-def test_from_id(mock_geoctx, mock_token):
-    mock_geoctx_graft = mock.PropertyMock(return_value={"returns": "geoctx"})
-    mock_token_graft = mock.PropertyMock(return_value={"returns": "_token_"})
-    type(mock_geoctx).graft = mock_geoctx_graft
-    type(mock_token).graft = mock_token_graft
-    # "Because of the way mock attributes are stored you can't directly attach a PropertyMock to a mock object.
-    # Instead you can attach it to the mock type object."
-    ImageCollection.from_id("foo")
-    mock_geoctx_graft.assert_called()
-    mock_token_graft.assert_called()
-
-
-@mock.patch.object(env, "geoctx")
-@mock.patch.object(env, "_token")
-def test_from_id_with_datetime(mock_geoctx, mock_token):
-    mock_geoctx_graft = mock.PropertyMock(return_value={"returns": "geoctx"})
-    mock_token_graft = mock.PropertyMock(return_value={"returns": "_token_"})
-    type(mock_geoctx).graft = mock_geoctx_graft
-    type(mock_token).graft = mock_token_graft
-    # "Because of the way mock attributes are stored you can't directly attach a PropertyMock to a mock object.
-    # Instead you can attach it to the mock type object."
-    ImageCollection.from_id(
-        "foo",
-        start_datetime="2018-05-17T00:00:00+00:00",
-        end_datetime="2019-05-17T00:00:00+00:00",
+def test_from_id():
+    assert isinstance(ImageCollection.from_id("foo"), ImageCollection)
+    assert isinstance(
+        ImageCollection.from_id(
+            "foo",
+            start_datetime="2020-01-01",
+            end_datetime="2021-01-01",
+            limit=1000,
+            resampler="near",
+            processing_level="toa",
+        ),
+        ImageCollection,
     )
-    mock_geoctx_graft.assert_called()
-    mock_token_graft.assert_called()
 
-
-@mock.patch.object(env, "geoctx")
-@mock.patch.object(env, "_token")
-def test_from_id_with_limit(mock_geoctx, mock_token):
-    mock_geoctx_graft = mock.PropertyMock(return_value={"returns": "geoctx"})
-    mock_token_graft = mock.PropertyMock(return_value={"returns": "_token_"})
-    type(mock_geoctx).graft = mock_geoctx_graft
-    type(mock_token).graft = mock_token_graft
-    # "Because of the way mock attributes are stored you can't directly attach a PropertyMock to a mock object.
-    # Instead you can attach it to the mock type object."
-    ImageCollection.from_id("foo", limit=10)
-    mock_geoctx_graft.assert_called()
-    mock_token_graft.assert_called()
+    with pytest.raises(ValueError, match="Unknown resampler type: 'foo'"):
+        ImageCollection.from_id("foo", resampler="foo")
+    with pytest.raises(ValueError, match="Unknown processing level: 'foo'"):
+        ImageCollection.from_id("foo", processing_level="foo")
 
 
 def test_stats_return_type():
@@ -117,6 +92,7 @@ def test_all_methods_nonstats():
     assert isinstance(col.index_to_coords(0, 0), Tuple[Float, Float])
     assert isinstance(col.coords_to_index(0.0, 0.0), Tuple[Int, Int])
     assert isinstance(col.mosaic(), Image)
+    assert isinstance(col.reduction("mosaic", axis="images"), Image)
     assert isinstance(col.concat(img), ImageCollection)
     assert isinstance(col.mask(img), ImageCollection)
     assert isinstance(col.mask(img, replace=True), ImageCollection)
@@ -154,7 +130,7 @@ def test_all_methods_nonstats():
 @pytest.mark.parametrize(
     "stats_func_name", ["min", "max", "mean", "median", "sum", "std", "count"]
 )
-def test_all_stats_methods(stats_func_name):
+def test_all_stats_methods_and_reduction(stats_func_name):
     col = ImageCollection.from_id("foo")
     stats_func = getattr(col, stats_func_name)
 
@@ -164,6 +140,9 @@ def test_all_stats_methods(stats_func_name):
         ImageCollection._RESOLVED_STATS_RETURN_TYPES
     ):
         assert isinstance(stats_func(axis=thaw_axis(axis)), return_type)
+        assert isinstance(
+            col.reduction(stats_func_name, axis=thaw_axis(axis)), return_type
+        )
 
 
 def test_properties():
